jinc_small_argument_fast

Function jinc_small_argument_fast 

pub(crate) fn jinc_small_argument_fast(x: f64) -> f64
This method on small range searches for nearest zero or extremum. Then picks stored series expansion at the point end evaluates the poly at the point.